import Taro from '@tarojs/taro'
import { Image, Button, View, Text, Input } from '@tarojs/components'
import SpinBox from "@/components/Spin/SpinBox";
import CustomCard from '@/components/foodCards/CustomCard/index'
import { useState, useEffect } from "react";
import BottomMoadl from '@/components/BottomMoadl/index'
import Travel from '@/assets/icons/Travel/travel.png'
import ChangeNext from '@/assets/icons/Travel/ChangeNext.png'
import withLayout from '@/layouts'
import Popup from '@/components/Popup';
import editImg from '@/assets/icons/Travel/editimg.png'
import CustomNav from '@/components/CustomNav'
import { deleteTravelItem, getTravelID, seaveTravelID } from '@/services/travel'

import './style.less'

export default withLayout((props) => {
  const { router, location } = props
  const { id, dayNum } = router.params

  const [loading, setLoading] = useState(false)
  //判断一天行程还是多天行程的标识位  一天就不用显示上一天下一天按钮
  const [bottomDayNum, setBottomDayNum] = useState(true)

  //获取当前行程当前天数的地点
  const [showCutover, setShowCutover] = useState([])
  //获取行程列表包括标题
  const [travelCustom, setTravelCustom] = useState()

  //文本框弹窗
  const [showDialog, setShowDialog] = useState(false);
  //行程标题获取弹窗的文本框的值
  const [inputChangle, setInputChangle] = useState();


  //第几天
  const [dayNumber, setDayNumber] = useState(1)
  //dayNum是当前行程的总天数   总天数减去当前是第几天sum代表剩余天数大于等于一代表后面还有所以下一天按钮可以出现
  const sum = dayNum - dayNumber
  //上一天按钮的标识位  如果是超过两天的话就显示上一天否则不显示 true代表不显示上一天  是第一天
  const [state, setstate] = useState(true)

  //下一天
  const addTextSum = () => {
    setDayNumber(dayNumber + 1)
    setstate(false)
  }
  //上一天
  const minusTextSum = () => {
    setDayNumber(dayNumber - 1)
    if (dayNumber == 2) {
      setstate(true)
    }
  }

  //获取我的行程。
  const getNowTravel = () => {
    setLoading(true)
    getTravelID(id).then(e => {
      setTravelCustom(e)
      //e.travelItemList代表当前行程所有天数的地点     dayNumber表示当前是第几天  filter就是筛选后的当前天数的地点
      setShowCutover(e.travelItemList.filter(item => item.dayOrder == dayNumber))
      setLoading(false)
    }).catch(e => {
      setLoading(false)
    })
  }

  useEffect(() => {
    if (dayNum == 1) {
      setBottomDayNum(false)
    } else {
      setBottomDayNum(true)
    }
    getNowTravel()
  }, [id, dayNumber])


  //删除行程
  const onDelete = (e) => {
    //这个删除是需要两个id的前一个id是整个行程的id需要根据这个id找到这条行程的全部信息  后面那个itemId是行程数组travelItemList里面的一条当前点击的需要删除的信息的id
    const itemId = e
    Taro.showModal({
      title: '提示',
      content: '确定要删除吗',
      success: function (res) {
        if (res.confirm) {
          deleteTravelItem(id, itemId).then(val => {
            Taro.showToast({
              title: '删除成功',
              icon: 'none',
              duration: 1000
            })
            getNowTravel()
          })
        }
      }
    })
  }

  //行程弹窗的标志位true表示弹出 false表示隐藏
  const [showFrame, setShowFrame] = useState(false)
  //行程推荐
  const setRecommend = () => {
    setShowFrame(!showFrame)
  }

  //修改行程名字实时获取文本框信息存到变量里面
  const handelInput = (e) => {
    setInputChangle(e.detail.value)
  }

  //取消
  const ButtonCancel = () => {
    setShowDialog(false)
  }
  //确认
  const ButtonOK = () => {
    seaveTravelID(id, { title: inputChangle }).then(val => {
      Taro.showToast({
        title: '修改成功',
        icon: 'none',
        duration: 1000
      })
      setShowDialog(false)
      getNowTravel()
    })
  }

  const handleModale = () => {
    // 弹窗弹出时给文本框变量赋初始值即数据库里的行程标题
    setInputChangle(travelCustom?.title)
    setShowDialog(true)
  }

  return (
    <View className='page-index box-content'>
      <View style={{ flex: 'none' }}>
        <Popup show={showDialog} maskClosable={false}>
          <View className='travel-box-info-ROOM'>
            <View className='travel-bi-name-ROOM' >
              <View className='travel-bin-title-ROOM'>修改行程名称：</View>
              <Input className='travel-bint-nameInfo-ROOM' value={inputChangle} onInput={handelInput} />
            </View>
          </View>
          <View className='travel-button-box' >
            <Button className='travelButton-Cancel' onClick={ButtonCancel} >取消</Button>
            <Button className='travelButton-OK' onClick={ButtonOK} >确定</Button>
          </View>
        </Popup>
        {/* 
        frameTitle 标题
        flag 弹窗显示 true false
        ico 底部图标
        textNext 底部文字
      */}
        <BottomMoadl frameTitle='行程推荐' dayNumber={dayNumber} travelId={id} flag={showFrame} handelAddTravel={getNowTravel} onRecommend={setRecommend} ico={ChangeNext} textNext='换一批' location={location} />
      </View>
      <View className='index-navbar'>
        <CustomNav title='定制行程' />
      </View>
      <View className='index-container'>
        <scroll-view scrollY style='height:100%;' >
          <View className='TravelTitle'>
            {travelCustom?.title}<Image src={editImg} className='edit' onClick={handleModale} ></Image>
          </View>
          <View className='index-container'>
            <SpinBox loading={loading}>
              <View className='View-box'>
                {
                  showCutover.map((item, index) =>
                    <CustomCard key={index} item={item} editable='1' travelId={item.travelId} onDelete={onDelete} />
                  )
                }
              </View>
            </SpinBox>
          </View>
          <View className='tuijian' onClick={setRecommend}>
            <Image src={Travel}></Image>
            <Text>查看行程推荐</Text>
          </View>
          {
            bottomDayNum &&
            <View className='bottom'>
              {
                state === false && <Button className='bottom-btn bottom-btn-cancel' onClick={minusTextSum} >上一天</Button>
              }
              {
                sum >= 1 && <Button className='bottom-btn bottom-btn-ok' onClick={addTextSum}>下一天</Button>
              }
            </View>
          }
        </scroll-view>
      </View>
    </View>
  )
})