import { useState, useEffect } from "react";
import Taro, { useDidShow } from '@tarojs/taro'
import MoreGuide from "@/components/MoreGuide";
import SpinBox from "@/components/Spin/SpinBox";
import { Image, View,Text } from "@tarojs/components";
import GPS from '@/assets/icons/GuideCheck/GPS.png'
import copy_logo from '@/assets/icons/GuideCheck/copy_logo.png'
import BlackSpot from '@/assets/icons/GuideCheck/BlackSpot.png'
import { getExtendContent } from '@/services/home'
import { getTaRoom, goToRoomForm } from '@/services/taRoom​'
import { useModel } from "@/store";
import Customized from '../components/Customized'
import './GuideCss/style.less'


export default (props) => {
  const { router, person, location, } = props
  let { roomId, roomOrderId } = router.params
  const [extend, setExtend] = useState([])
  const [ifroomId, setIfroomId] = useState('havenot')
  const [loading, setLoading] = useState(false)

  const { roomId: rid } = useModel('hotel')

  if (!roomId && rid) {
    roomId = rid
  }

  const [taRoomContent, setTaRoomContent] = useState([])

  const goContent = () => {
    if (roomOrderId) {
      goToRoomForm(roomOrderId).then((res) => {
        if (res.status !== 1 && res.personNum > 0) {
          Taro.reLaunch({
            url: `/pages/RoomOrder/index?roomOrderId=${roomOrderId}&status=${res.status}&roomId=${roomId}`,
          })
        }
      })
    }
  }

  useDidShow(() => {
    goContent()
  })

  const getGuidelist = () => {
    setLoading(true)
    getExtendContent('room', roomId, { pageSize: 500 }).then((res) => {
      setExtend(res.records || [])
      setIfroomId('reality')
      setLoading(false)
    })
    setLoading(true)
  }

  useEffect(() => {
    if (roomId) {
      setLoading(true)
      // 点击’去这里‘跳转导航
      getTaRoom(roomId).then((res) => {
        setTaRoomContent(res || [])
        setLoading(false)
      })
      //更多指引
      getGuidelist()
    }
  }, [roomId, taRoomContent?.wifiPassword, taRoomContent?.parkingAddress, location, taRoomContent.location])


  const goRoomMap = () => {
    if (taRoomContent.location) {
      const [longitude, latitude] = taRoomContent.location.split(',').map(x => x - 0)

      Taro.openLocation({
        longitude,
        latitude,
        name: taRoomContent.roomName,
        address: taRoomContent.address,
        scale: 12,
      })
    }
  }

  const goParkMap = () => {
    if (taRoomContent.parkingLocation) {
      const [longitude, latitude] = taRoomContent.parkingLocation.split(',').map(x => x - 0)

      Taro.openLocation({
        longitude,
        latitude,
        name: taRoomContent.parkingAddress,
        address: taRoomContent.parkingAddress,
        scale: 12,
      })
    }
  }

  const wifiCopy = () => {
    Taro.setClipboardData({
      data: taRoomContent?.wifiPassword,
      success: e => {
        Taro.showToast({
          title: '密码已复制',
          icon: 'success',
          duration: 2000,
        })
      }
    })
  }
  const goIndex = () => {
    Taro.redirectTo({ url: '/pages/index/index' })
  }
  return (
    <scroll-view scrollY style={{ height: '100%' }}  >
      <View className='Guide-Home-box'>
        {/* 有民宿的情况下 */}
        {
          ifroomId === 'reality' && (
            <SpinBox loading={loading}>
              <View className='room-box-info-ROOM'>
                <View className='room-bi-name-ROOM' >
                  <View className='room-bin-title-ROOM'>房屋名称</View>
                  <View className='room-bint-nameInfo-ROOM'>{taRoomContent?.roomName}
                  </View>
                </View>
              </View>
              {/* --------房屋位置-------- */}
              <View className='room-box-info-HouLocation'>
                <View className='room-bi-name-HouLocation' >
                  <View className='room-bin-title-HouLocation'>房屋位置</View>
                  <View className='room-bint-nameInfo-HouLocation'>
                    <View className='room-bint-nameInfo-bool-HouLocation' >{taRoomContent?.address}</View>
                    <View className='room-bintn-button-HouLocation' onClick={() => { goRoomMap() }}>
                      <Image className='room-bintn-image-HouLocation' src={GPS} />
                      <Text className='room-bintn-text-HouLocation'>去这里</Text>
                    </View>
                  </View>
                </View>
              </View>
              {/* --------停车场-------- */}
              {
                !taRoomContent.parkingLocation ? null :
                  <View className='room-box-info-Parking'>
                    <View className='room-bi-name-Parking' >
                      <View className='room-bin-title-Parking'>停车位置</View>
                      <View className='room-bint-nameInfo-Parking'>
                        <View className='room-bint-nameInfo-bool-Parking' >{taRoomContent?.parkingAddress}</View>
                        <View className='room-bintn-button-Parking' onClick={() => { goParkMap() }}>
                          <Image className='room-bintn-image-Parking' src={GPS} />
                          <Text className='room-bintn-text-Parking'>去这里</Text>
                        </View>
                      </View>
                    </View>
                  </View>
              }
              {/* --------无线网-------- */}
              {
                !taRoomContent.wifiName && !taRoomContent.wifiPassword ? null :
                  <View className='room-box-info-WIFIContent'>
                    <View className='room-bi-name-WIFIContent' >
                      <View className='room-bin-title-WIFIContent'>WiFi信息</View>
                      <View className='room-bint-nameInfo-WIFIContent'>
                        <View className='room-bint-nameInfo-bool-WIFIContent-wifi' >名称：{taRoomContent?.wifiName}</View>
                        <View className='room-bint-nameInfo-bool-WIFIContent-password' >密码：{taRoomContent?.wifiPassword}</View>
                        <View className='room-bintn-button-WIFIContent' onClick={() => { wifiCopy() }}>
                          <Image className='room-bintn-image-WIFIContent' src={copy_logo} />
                          <Text className='room-bintn-text-WIFIContent'>复制</Text>
                        </View>
                      </View>
                    </View>
                  </View>
              }
              {
                extend.length === 0 ? null :
                  <View className='Guide-Content-box'  >
                    <View className='title-image'>
                      <Image mode='scaleToFill' className='title-image-cup' src={BlackSpot} />
                      <Text className='title-title-boss' >更多指引</Text>
                    </View>
                    <View>
                      {(extend || []).map((item, index) => <MoreGuide key={(index)} item={item} />)}
                    </View>
                  </View>
              }
            </SpinBox>
          )
        }
        <View className='Guide-Content-box'>
          <Customized />
        </View>
        <View>
          <Image mode='widthFix' style={{ width: '100%' }} src='http://yz-shigongli.oss-cn-shanghai.aliyuncs.com/images/hotel_guide_help.png' onClick={goIndex} />
        </View>
      </View>
    </scroll-view>
  )
}